Name:           xmlrpc
Version:        3.1.3
Release:        %mkrel 80
Group:          Development/Java
Epoch:          1
Summary:        Java XML-RPC implementation
License:        ASL 2.0
URL:            https://ws.apache.org/xmlrpc/
BuildArch:      noarch

Source0:        https://archive.apache.org/dist/ws/xmlrpc/sources/apache-xmlrpc-%{version}-src.tar.bz2

# Fix build against modern servlet API by implementing missing interfaces
Patch0: 0001-Javax-Servlet-API.patch
# Add OSGi metadata so that xmlrpc can be used in OSGi runtimes
Patch1: 0002-Add-OSGi-metadata.patch
# CVE-2016-5003 - Disallow deserialization of <ex:serializable> tags by default
Patch2: 0003-disallow-deserialization-of-ex-serializable-tags.patch
# CVE-2016-5002 - isallow loading of external DTD
Patch3: 0004-disallow-loading-external-dtd.patch
# Jakarta Commons HttpClient is obsolete and should not be used, one of the other
# provider implementations should by used instead by clients of xmlrpc
Patch4: 0005-Remove-dep-on-ancient-commons-httpclient.patch
# CVE-2019-17570 - Deserialization of server-side exception from faultCause in XMLRPC error response
Patch5: 0006-Fix-for-CVE-2019-17570.patch

BuildRequires:  maven-local
BuildRequires:  mvn(commons-logging:commons-logging)
BuildRequires:  mvn(javax.servlet:javax.servlet-api)
BuildRequires:  mvn(javax.xml.bind:jaxb-api)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache:apache:pom:)
BuildRequires:  mvn(org.apache.ws.commons.util:ws-commons-util)

%description
Apache XML-RPC is a Java implementation of XML-RPC, a popular protocol
that uses XML over HTTP to implement remote procedure calls.

%package javadoc
Summary: Javadoc for %{name}

%description javadoc
Javadoc for %{name}.

%package common
Summary: Common classes for XML-RPC client and server implementations

%description common
%{summary}.

%package client
Summary: XML-RPC client implementation

%description client
%{summary}.

%package server
Summary: XML-RPC server implementation

%description server
%{summary}.

%prep
%setup -q -n apache-%{name}-%{version}-src

%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1

sed -i 's/\r//' LICENSE.txt

%pom_disable_module dist
%pom_remove_dep jaxme:jaxmeapi common
%pom_add_dep junit:junit:3.8.1:test

%pom_remove_plugin :maven-javadoc-plugin

# Add missing dep when building against Java 11
%pom_add_dep javax.xml.bind:jaxb-api:2.2.12

# don't hard code source and target levels
sed -i -e '/<source>/d' \
       -e '/<target>/d' pom.xml

%mvn_file :{*} @1
%mvn_package :*-common %{name}

%build
# ignore test failure because server part needs network
%mvn_build -s -- -Dmaven.test.failure.ignore=true \
  -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

%install
%mvn_install

%files common -f .mfiles-%{name}
%license LICENSE.txt NOTICE.txt

%files client -f .mfiles-%{name}-client

%files server -f .mfiles-%{name}-server

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt




%changelog
* Mon May 27 2024 ns80 <ns80> 1:3.1.3-80.mga10
+ Revision: 2068009
- rebuild for java 21

* Sat Mar 26 2022 umeabot <umeabot> 1:3.1.3-79.mga9
+ Revision: 1827665
- Mageia 9 Mass Rebuild

* Mon Jan 04 2021 neoclust <neoclust> 1:3.1.3-78.mga8
+ Revision: 1668715
- Do not use old commons httpclient

* Mon Dec 21 2020 neoclust <neoclust> 1:3.1.3-77.mga8
+ Revision: 1662676
- Disable tests
+ luigiwalser <luigiwalser>
- allow building on Java 11

* Thu Feb 20 2020 umeabot <umeabot> 1:3.1.3-75.mga8
+ Revision: 1545968
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 1:3.1.3-74.mga8
+ Revision: 1485690
- add patch to fix CVE-2019-17570 (mga#26090)

* Tue Jan 01 2019 luigiwalser <luigiwalser> 1:3.1.3-73.mga7
+ Revision: 1347897
- add patches from fedora to fix CVE-2016-500[23]

* Wed Sep 19 2018 umeabot <umeabot> 1:3.1.3-72.mga7
+ Revision: 1277257
- Mageia 7 Mass Rebuild
+ neoclust <neoclust>
- Second rebuild of the java stack

* Thu Feb 18 2016 umeabot <umeabot> 1:3.1.3-70.mga6
+ Revision: 965244
- Mageia 6 Mass Rebuild

* Fri Dec 26 2014 dmorgan <dmorgan> 1:3.1.3-69.mga5
+ Revision: 806149
- Sync with fc21

* Wed Oct 15 2014 umeabot <umeabot> 1:3.1.3-7.mga5
+ Revision: 742115
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Mon Jul 07 2014 pterjan <pterjan> 1:3.1.3-5.mga5
+ Revision: 650326
- Sync with fedora (fixes build)

* Tue Oct 22 2013 dmorgan <dmorgan> 1:3.1.3-4.mga4
+ Revision: 546278
- Build with xmvn
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 luigiwalser <luigiwalser> 1:3.1.3-2.mga4
+ Revision: 494406
- BR maven-local for mvn-rpmbuild

* Thu Jan 17 2013 dmorgan <dmorgan> 1:3.1.3-1.mga3
+ Revision: 389214
- New version 3.1.3
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Apr 27 2011 dmorgan <dmorgan> 0:2.0.1-10.mga1
+ Revision: 92197
- Sync with fedora spec file
  Remove gcj support

* Fri Jan 21 2011 ennael <ennael> 0:2.0.1-8.mga1
+ Revision: 30420
- imported package xmlrpc


* Sat Dec 04 2010 Oden Eriksson <oeriksson@mandriva.com> 0:2.0.1-8mdv2011.0
+ Revision: 608223
- rebuild

* Sun Mar 14 2010 Oden Eriksson <oeriksson@mandriva.com> 0:2.0.1-7mdv2010.1
+ Revision: 519081
- rebuild

* Wed Jun 18 2008 Thierry Vignaud <tv@mandriva.org> 0:2.0.1-6mdv2009.0
+ Revision: 226066
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 0:2.0.1-5mdv2008.1
+ Revision: 121060
- buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)
- remove unnecessary Requires(post) on java-gcj-compat

* Sun Jun 10 2007 David Walluck <walluck@mandriva.org> 0:2.0.1-3mdv2008.0
+ Revision: 37945
- birthday rebuild
- spec file cleanup
- Import xmlrpc



* Sun Jun 04 2006 David Walluck <walluck@mandriva.org> 0:2.0.1-2mdv2007.0
- rebuild for libgcj.so.7
- fix gcj support

* Wed Feb 22 2006 David Walluck <walluck@mandriva.org> 0:2.0.1-1mdk
- release (0:2.0.1-1jpp_4fc)

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 0:2.0.1-1jpp_4fc
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 0:2.0.1-1jpp_3fc
- rebuilt for new gcc4.1 snapshot and glibc changes

* Wed Jan 25 2006 Igor Foox <ifoox@redhat.com>  0:2.0.1-1jpp_2fc
- ExcludeArch s390x and ppc64

* Wed Jan 18 2006 Andrew Overholt <overholt@redhat.com> 0:2.0.1-1jpp_2fc
- Comment out JPackage Distribution and Vendor tags

* Wed Jan 18 2006 Jesse Keating <jkeating@redhat.com> 0:2.0.1-1jpp_2fc
- bump for test

* Wed Jan 18 2006 Igor Foox <ifoox@redhat.com> 0:2.0.1-1jpp_1fc
- Update to version 2.0.1
- Natively compile

* Thu Aug 26 2004 Ralph Apel <r.apel at r-apel.de> 0:1.2-0.b1.3jpp
- Build with ant-1.6.2

* Thu Apr 29 2004 David Walluck <david@jpackage.org> 0:1.2-0.b1.2jpp
- add jar symlinks
- remove %%buildroot in %%install

* Tue May 06 2003 David Walluck <david@anti-microsoft.org> 0:1.2-0.b1.1jpp
- 1.2-b1
- update for JPackage 1.5

* Mon Mar 18 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1-1jpp 
- 1.1
- generic servlet support
- used source release
- dropped.patch.bz2
- added applet jar

* Mon Jan 21 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.0-3jpp 
- versioned dir for javadoc
- no dependencies for javadoc package
- dropped jsse package
- adaptation to new servlet3 package
- adaptation to new jsse package
- section macro

* Fri Dec 7 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.0-2jpp
- javadoc into javadoc package

* Sat Nov 3 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.0-1jpp
- first JPackage release
